@@ -3,9 +3,10 @@ from __future__ import unicode_literals
 import base64
 import hashlib
 
+from django.contrib.auth import get_user_model
 from django.core.urlresolvers import reverse
+from django.utils.encoding import smart_bytes, force_text
 
-from allaccess.compat import get_user_model, smart_bytes, force_text
 from allaccess.views import OAuthRedirect, OAuthCallback
 
 
