@@ -6,15 +6,14 @@ import logging
 
 from django.conf import settings
 from django.contrib import messages
-from django.contrib.auth import authenticate, login
+from django.contrib.auth import authenticate, login, get_user_model
 from django.core.urlresolvers import reverse
-from django.http import Http404, HttpResponse
+from django.http import Http404
 from django.shortcuts import redirect
+from django.utils.encoding import smart_bytes, force_text
 from django.views.generic import RedirectView, View
 
 from .clients import get_client
-from .compat import smart_bytes, force_text
-from .compat import get_user_model
 from .models import Provider, AccountAccess
 
 
@@ -37,10 +36,11 @@ class OAuthRedirect(OAuthClientMixin, RedirectView):
     "Redirect user to OAuth provider to enable access."
 
     permanent = False
+    params = None
 
     def get_additional_parameters(self, provider):
         "Return additional redirect parameters for this provider."
-        return {}
+        return self.params or {}
 
     def get_callback_url(self, provider):
         "Return the callback url for this provider."
@@ -65,6 +65,8 @@ class OAuthRedirect(OAuthClientMixin, RedirectView):
 class OAuthCallback(OAuthClientMixin, View):
     "Base OAuth callback view."
 
+    provider_id = None
+
     def get(self, request, *args, **kwargs):
         name = kwargs.get('provider', '')
         try:
@@ -131,9 +133,14 @@ class OAuthCallback(OAuthClientMixin, View):
 
     def get_user_id(self, provider, info):
         "Return unique identifier from the profile info."
-        if hasattr(info, 'get'):
-            return info.get('id')
-        return None
+        id_key = self.provider_id or 'id'
+        result = info
+        try:
+            for key in id_key.split('.'):
+                result = result[key]
+            return result
+        except KeyError:
+            return None
 
     def handle_existing_user(self, provider, user, access, info):
         "Login user and redirect."
